@@ -32,7 +32,6 @@ import six
 import humanize
 
 from rattail.db import model
-from rattail.time import make_utc
 from rattail.util import pretty_quantity
 
 from deform import widget as dfwidget
@@ -392,7 +391,7 @@ class ReceivingBatchRowViews(APIBatchRowView):
             data['received_alert'] = None
             if self.handler.get_units_confirmed(row):
                 msg = "You have already received some of this product; last update was {}.".format(
-                    humanize.naturaltime(make_utc() - row.modified))
+                    humanize.naturaltime(app.make_utc() - row.modified))
                 data['received_alert'] = msg
 
         return data
@@ -444,6 +443,15 @@ class ReceivingBatchRowViews(APIBatchRowView):
                         renderer='json')
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    ReceivingBatchViews = kwargs.get('ReceivingBatchViews', base['ReceivingBatchViews'])
     ReceivingBatchViews.defaults(config)
+
+    ReceivingBatchRowViews = kwargs.get('ReceivingBatchRowViews', base['ReceivingBatchRowViews'])
     ReceivingBatchRowViews.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
