@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -129,5 +129,12 @@ class CommonView(APIView):
         config.add_cornice_service(feedback)
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    CommonView = kwargs.get('CommonView', base['CommonView'])
     CommonView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
