@@ -37,6 +37,7 @@ from sqlalchemy.ext.associationproxy import AssociationProxy, ASSOCIATION_PROXY
 from rattail.time import localtime
 from rattail.util import prettify, pretty_boolean, pretty_quantity
 from rattail.core import UNSPECIFIED
+from rattail.db.util import get_fieldnames
 
 import colander
 import deform
@@ -396,19 +397,8 @@ class Form(object):
         if not self.model_class:
             raise ValueError("Must define model_class to use make_fields()")
 
-        mapper = orm.class_mapper(self.model_class)
-
-        # first add primary column fields
-        fields = FieldList([prop.key for prop in mapper.iterate_properties
-                            if not prop.key.startswith('_')
-                            and prop.key != 'versions'])
-
-        # then add association proxy fields
-        for key, desc in sa.inspect(self.model_class).all_orm_descriptors.items():
-            if desc.extension_type == ASSOCIATION_PROXY:
-                fields.append(key)
-
-        return fields
+        return get_fieldnames(self.request.rattail_config, self.model_class,
+                              columns=True, proxies=True, relations=True)
 
     def make_renderers(self):
         """
@@ -904,10 +894,19 @@ class Form(object):
             # show errors if present
             error_messages = self.get_error_messages(field)
             if error_messages:
+
+                # TODO: this surely can't be what we ought to do
+                # here..?  seems like we must pass JS but not JSON,
+                # sort of, so we custom-write the JS code to ensure
+                # single instead of double quotes delimit strings
+                # within the code.
+                message = '[{}]'.format(', '.join([
+                    "'{}'".format(msg.replace("'", r"\'"))
+                    for msg in error_messages]))
+
                 attrs.update({
                     'type': 'is-danger',
-                    # ':message': self.messages_json(error_messages),
-                    ':message': error_messages,
+                    ':message': message,
                 })
 
             # merge anything caller provided
