@@ -289,6 +289,95 @@ class JQueryAutocompleteWidget(dfwidget.AutocompleteInputWidget):
         return field.renderer(template, **tmpl_values)
 
 
+def make_customer_widget(request, **kwargs):
+    """
+    Make a customer widget; will be either autocomplete or dropdown
+    depending on config.
+    """
+    # use autocomplete widget by default
+    factory = CustomerAutocompleteWidget
+
+    # caller may request dropdown widget
+    if kwargs.pop('dropdown', False):
+        factory = CustomerDropdownWidget
+
+    else: # or, config may say to use dropdown
+        if request.rattail_config.getbool(
+                'rattail', 'customers.choice_uses_dropdown',
+                default=False):
+            factory = CustomerDropdownWidget
+
+    # instantiate whichever
+    return factory(request, **kwargs)
+
+
+class CustomerAutocompleteWidget(JQueryAutocompleteWidget):
+    """
+    Autocomplete widget for a Customer reference field.
+    """
+
+    def __init__(self, request, *args, **kwargs):
+        super(CustomerAutocompleteWidget, self).__init__(*args, **kwargs)
+        self.request = request
+        model = self.request.rattail_config.get_model()
+
+        # must figure out URL providing autocomplete service
+        if 'service_url' not in kwargs:
+
+            # caller can just pass 'url' instead of 'service_url'
+            if 'url' in kwargs:
+                self.service_url = kwargs['url']
+
+            else: # use default url
+                self.service_url = self.request.route_url('customers.autocomplete')
+
+        # TODO
+        if 'input_callback' not in kwargs:
+            if 'input_handler' in kwargs:
+                self.input_callback = input_handler
+
+    def serialize(self, field, cstruct, **kw):
+
+        # fetch customer to provide button label, if we have a value
+        if cstruct:
+            model = self.request.rattail_config.get_model()
+            customer = Session.query(model.Customer).get(cstruct)
+            if customer:
+                self.field_display = six.text_type(customer)
+
+        return super(CustomerAutocompleteWidget, self).serialize(
+            field, cstruct, **kw)
+
+
+class CustomerDropdownWidget(dfwidget.SelectWidget):
+    """
+    Dropdown widget for a Customer reference field.
+    """
+
+    def __init__(self, request, *args, **kwargs):
+        super(CustomerDropdownWidget, self).__init__(*args, **kwargs)
+        self.request = request
+
+        # must figure out dropdown values, if they weren't given
+        if 'values' not in kwargs:
+
+            # use what caller gave us, if they did
+            if 'customers' in kwargs:
+                customers = kwargs['customers']
+                if callable(customers):
+                    customers = customers()
+
+            else: # default customer list
+                model = self.request.rattail_config.get_model()
+                customers = Session.query(model.Customer)\
+                                   .order_by(model.Customer.name)\
+                                   .all()
+
+            # convert customer list to option values
+            self.values = [(c.uuid, c.name)
+                           for c in customers]
+
+
 class DepartmentWidget(dfwidget.SelectWidget):
     """
     Custom select widget for a Department reference field.
