@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -682,6 +682,47 @@ class AlchemyDateFilter(AlchemyGridFilter):
             else:
                 return dt.date()
 
+    def filter_equal(self, query, value):
+        date = self.make_date(value)
+        if not date:
+            return query
+
+        return query.filter(self.column == self.encode_value(date))
+
+    def filter_not_equal(self, query, value):
+        date = self.make_date(value)
+        if not date:
+            return query
+
+        return query.filter(sa.or_(
+            self.column == None,
+            self.column != self.encode_value(date),
+        ))
+
+    def filter_greater_than(self, query, value):
+        date = self.make_date(value)
+        if not date:
+            return query
+        return query.filter(self.column > self.encode_value(date))
+
+    def filter_greater_equal(self, query, value):
+        date = self.make_date(value)
+        if not date:
+            return query
+        return query.filter(self.column >= self.encode_value(date))
+
+    def filter_less_than(self, query, value):
+        date = self.make_date(value)
+        if not date:
+            return query
+        return query.filter(self.column < self.encode_value(date))
+
+    def filter_less_equal(self, query, value):
+        date = self.make_date(value)
+        if not date:
+            return query
+        return query.filter(self.column <= self.encode_value(date))
+
     def filter_between(self, query, value):
         """
         Filter data with a "between" query.  Really this uses ">=" and "<="
