@@ -20,7 +20,7 @@ const NumericInput = {
 
     props: {
         name: String,
-        value: String,
+        value: [Number, String],
         placeholder: String,
         iconPack: String,
         icon: String,
@@ -53,6 +53,10 @@ const NumericInput = {
             }
         },
 
+        select() {
+            this.$el.children[0].select()
+        },
+
         valueChanged(value) {
             this.$emit('input', value)
         }
