@@ -127,6 +127,8 @@ def raw_datetime(config, value, verbose=False, as_date=False):
     if not value:
         return ''
 
+    app = config.get_app()
+
     # Make sure we're dealing with a tz-aware value.  If we're given a naive
     # value, we assume it to be local to the UTC timezone.
     if not value.tzinfo:
@@ -150,10 +152,8 @@ def raw_datetime(config, value, verbose=False, as_date=False):
     else:
         kwargs['c'] = six.text_type(value)
 
-    # avoid humanize error when calculating huge time diff
-    time_diff = None
-    if abs(time_ago.days) < 100000:
-        time_diff = humanize.naturaltime(time_ago)
+    time_diff = app.render_time_ago(time_ago, fallback=None)
+    if time_diff is not None:
 
         # by "verbose" we mean the result text to look like "YYYY-MM-DD (X days ago)"
         if verbose:
