@@ -29,9 +29,7 @@ from __future__ import unicode_literals, absolute_import
 import os
 import six
 
-from rattail.db import model
 from rattail.batch import consume_batch_id
-from rattail.mail import send_email
 from rattail.util import OrderedDict, simple_error, import_module_path
 from rattail.files import resource_path
 
@@ -172,6 +170,8 @@ class CommonView(View):
         """
         Generic view to handle the user feedback form.
         """
+        app = self.get_rattail_app()
+        model = self.model
         schema = Feedback().bind(session=Session())
         form = forms.Form(schema=schema, request=self.request)
         if form.validate(newstyle=True):
@@ -180,7 +180,7 @@ class CommonView(View):
                 data['user'] = Session.query(model.User).get(data['user'])
                 data['user_url'] = self.request.route_url('users.view', uuid=data['user'].uuid)
             data['client_ip'] = self.request.client_addr
-            send_email(self.rattail_config, 'user_feedback', data=data)
+            app.send_email('user_feedback', data=data)
             return {'ok': True}
         return {'error': "Form did not validate!"}
 
