@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -134,12 +134,12 @@ class View(object):
     def progress_loop(self, func, items, factory, *args, **kwargs):
         return progress_loop(func, items, factory, *args, **kwargs)
 
-    def make_progress(self, key):
+    def make_progress(self, key, **kwargs):
         """
         Create and return a :class:`tailbone.progress.SessionProgress`
         instance, with the given key.
         """
-        return SessionProgress(self.request, key)
+        return SessionProgress(self.request, key, **kwargs)
 
     # TODO: this signature seems wonky
     def render_progress(self, progress, kwargs, template=None):
