@@ -410,8 +410,7 @@ class CustomerOrderView(MasterView):
         self.request.session.flash("New customer order has been deleted.")
 
         # send user back to customer orders page, w/ no new batch generated
-        route_prefix = self.get_route_prefix()
-        url = self.request.route_url(route_prefix)
+        url = self.get_index_url()
         return self.redirect(url)
 
     def customer_autocomplete(self):
@@ -925,11 +924,16 @@ class CustomerOrderView(MasterView):
             if not result:
                 return {'error': "Batch failed to execute"}
 
-        next_url = None
-        if isinstance(result, model.CustomerOrder):
-            next_url = self.get_action_url('view', result)
+        return {
+            'ok': True,
+            'next_url': self.get_next_url_after_submit_new_order(batch, result),
+        }
 
-        return {'ok': True, 'next_url': next_url}
+    def get_next_url_after_submit_new_order(self, batch, result, **kwargs):
+        model = self.model
+
+        if isinstance(result, model.CustomerOrder):
+            return self.get_action_url('view', result)
 
     def execute_new_order_batch(self, batch, data):
         return self.batch_handler.do_execute(batch, self.request.user)
@@ -1005,5 +1009,12 @@ class CustomerOrderView(MasterView):
 CustomerOrdersView = CustomerOrderView
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    CustomerOrderView = kwargs.get('CustomerOrderView', base['CustomerOrderView'])
     CustomerOrderView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
