@@ -304,6 +304,11 @@ class EmployeeView(MasterView):
             items.append(HTML.tag('li', c=six.text_type(department)))
         return HTML.tag('ul', c=items)
 
+    def touch_instance(self, employee):
+        app = self.get_rattail_app()
+        employment = app.get_employment_handler()
+        employment.touch_employee(self.Session(), employee)
+
     def get_version_child_classes(self):
         return [
             (model.Person, 'uuid', 'person_uuid'),
