@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -576,13 +576,19 @@ cd {prefix}
         return settings
 
     def configure_remove_settings(self):
+        app = self.get_rattail_app()
         model = self.model
-        self.Session.query(model.Setting)\
-                    .filter(sa.or_(
-                        model.Setting.name.like('rattail.importing.%.handler'),
-                        model.Setting.name.like('rattail.importing.%.cmd'),
-                        model.Setting.name.like('rattail.importing.%.runas')))\
-                    .delete(synchronize_session=False)
+        session = self.Session()
+
+        to_delete = session.query(model.Setting)\
+                           .filter(sa.or_(
+                               model.Setting.name.like('rattail.importing.%.handler'),
+                               model.Setting.name.like('rattail.importing.%.cmd'),
+                               model.Setting.name.like('rattail.importing.%.runas')))\
+                           .all()
+
+        for setting in to_delete:
+            app.delete_setting(session, setting)
 
     @classmethod
     def defaults(cls, config):
