@@ -95,10 +95,13 @@ class PersonView(MasterView):
 
     def __init__(self, request):
         super(PersonView, self).__init__(request)
+        app = self.get_rattail_app()
 
         # always get a reference to the People Handler
-        app = self.get_rattail_app()
-        self.handler = app.get_people_handler()
+        self.people_handler = app.get_people_handler()
+        self.merge_handler = self.people_handler
+        # TODO: deprecate / remove this
+        self.handler = self.people_handler
 
     def make_grid_kwargs(self, **kwargs):
         kwargs = super(PersonView, self).make_grid_kwargs(**kwargs)
@@ -396,31 +399,6 @@ class PersonView(MasterView):
             (model.VendorContact, 'person_uuid'),
         ]
 
-    def get_merge_fields(self):
-        fields = self.handler.get_merge_preview_fields()
-        return [field['name'] for field in fields]
-
-    def get_merge_additive_fields(self):
-        fields = self.handler.get_merge_preview_fields()
-        return [field['name'] for field in fields
-                if field.get('additive')]
-
-    def get_merge_coalesce_fields(self):
-        fields = self.handler.get_merge_preview_fields()
-        return [field['name'] for field in fields
-                if field.get('coalesce')]
-
-    def get_merge_data(self, person):
-        return self.handler.get_merge_preview_data(person)
-
-    def validate_merge(self, removing, keeping):
-        reason = self.handler.why_not_merge(removing, keeping)
-        if reason:
-            raise Exception(reason)
-
-    def merge_objects(self, removing, keeping):
-        self.handler.perform_merge(removing, keeping, user=self.request.user)
-
     def view_profile(self):
         """
         View which exposes the "full profile" for a given person, i.e. all
@@ -469,6 +447,9 @@ class PersonView(MasterView):
     def get_max_lengths(self):
         model = self.model
         return {
+            'person_first_name': maxlen(model.Person.first_name),
+            'person_middle_name': maxlen(model.Person.middle_name),
+            'person_last_name': maxlen(model.Person.last_name),
             'address_street': maxlen(model.PersonMailingAddress.street),
             'address_street2': maxlen(model.PersonMailingAddress.street2),
             'address_city': maxlen(model.PersonMailingAddress.city),
