@@ -28,7 +28,6 @@ from __future__ import unicode_literals, absolute_import
 
 import copy
 
-from rattail.db.auth import has_permission
 from rattail.core import Object
 from rattail.util import OrderedDict
 
@@ -144,6 +143,9 @@ class PermissionsRenderer(Object):
         return self.render()
 
     def render(self):
+        app = self.request.rattail_config.get_app()
+        auth = app.get_auth_handler()
+
         principal = self.principal
         html = ''
         for groupkey in sorted(self.permissions, key=lambda k: self.permissions[k]['label'].lower()):
@@ -151,9 +153,9 @@ class PermissionsRenderer(Object):
             perms = self.permissions[groupkey]['perms']
             rendered = False
             for key in sorted(perms, key=lambda p: perms[p]['label'].lower()):
-                checked = has_permission(Session(), principal, key,
-                                         include_guest=self.include_guest,
-                                         include_authenticated=self.include_authenticated)
+                checked = auth.has_permission(Session(), principal, key,
+                                              include_guest=self.include_guest,
+                                              include_authenticated=self.include_authenticated)
                 if checked:
                     label = perms[key]['label']
                     span = HTML.tag('span', c="[X]" if checked else "[ ]")
