@@ -83,6 +83,7 @@ class ProductView(MasterView):
     has_versions = True
     results_downloadable_xlsx = True
     supports_autocomplete = True
+    mergeable = True
     configurable = True
 
     labels = {
@@ -180,6 +181,7 @@ class ProductView(MasterView):
 
         app = self.get_rattail_app()
         self.products_handler = app.get_products_handler()
+        self.merge_handler = self.products_handler
         # TODO: deprecate / remove these
         self.product_handler = self.products_handler
         self.handler = self.products_handler
