@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -53,6 +53,7 @@ class OrderingBatchView(PurchasingBatchView):
     index_title = "Ordering"
     rows_editable = True
     has_worksheet = True
+    default_help_url = 'https://rattailproject.org/docs/rattail-manual/features/purchasing/ordering/index.html'
 
     labels = {
         'po_total_calculated': "PO Total",
@@ -389,7 +390,7 @@ class OrderingBatchView(PurchasingBatchView):
             if cases_ordered == '':
                 cases_ordered = 0
             else:
-                cases_ordered = int(cases_ordered)
+                cases_ordered = int(float(cases_ordered))
         if cases_ordered >= 100000: # TODO: really this depends on underlying column
             return {'error': "Invalid value for cases ordered: {}".format(cases_ordered)}
 
@@ -400,7 +401,7 @@ class OrderingBatchView(PurchasingBatchView):
             if units_ordered == '':
                 units_ordered = 0
             else:
-                units_ordered = int(units_ordered)
+                units_ordered = int(float(units_ordered))
         if units_ordered >= 100000: # TODO: really this depends on underlying column
             return {'error': "Invalid value for units ordered: {}".format(units_ordered)}
 
