@@ -80,6 +80,7 @@ class ReceivingBatchView(PurchasingBatchView):
     bulk_deletable = True
     configurable = True
     config_title = "Receiving"
+    default_help_url = 'https://rattailproject.org/docs/rattail-manual/features/purchasing/receiving/index.html'
 
     rows_editable = False
     rows_editable_but_not_directly = True
@@ -1927,6 +1928,9 @@ class ReceivingBatchView(PurchasingBatchView):
             {'section': 'rattail.batch',
              'option': 'purchase.allow_expired_credits',
              'type': bool},
+            {'section': 'rattail.batch',
+             'option': 'purchase.receiving.should_autofix_invoice_case_vs_unit',
+             'type': bool},
 
             # mobile interface
             {'section': 'rattail.batch',
