@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -28,12 +28,12 @@ from __future__ import unicode_literals, absolute_import
 
 import re
 
+import json
 import six
 
-from rattail.db import model, api
+from rattail.db import model
 from rattail.settings import Setting
 from rattail.util import import_module_path
-from rattail.config import parse_bool
 
 import colander
 from webhelpers2.html import tags
@@ -80,11 +80,26 @@ class SettingView(MasterView):
             return not bool(self.feedback.match(setting.name))
         return True
 
+    def after_edit(self, setting):
+        # nb. force cache invalidation - normally this happens when a
+        # setting is saved via app handler, but here that is being
+        # bypassed and it is saved directly via standard ORM calls
+        self.rattail_config.beaker_invalidate_setting(setting.name)
+
     def deletable_instance(self, setting):
         if self.rattail_config.demo():
             return not bool(self.feedback.match(setting.name))
         return True
 
+    def delete_instance(self, setting):
+
+        # nb. force cache invalidation
+        self.rattail_config.beaker_invalidate_setting(setting.name)
+
+        # otherwise delete like normal
+        super(SettingView, self).delete_instance(setting)
+
+
 # TODO: deprecate / remove this
 SettingsView = SettingView
 
@@ -171,14 +186,28 @@ class AppSettingsView(View):
                 'data_type': setting.data_type.__name__,
                 'choices': setting.choices,
                 'helptext': form.render_helptext(field.name) if form.has_helptext(field.name) else None,
-                'error': field.error,
+                'error': False, # nb. may set to True below
             }
-            value = self.get_setting_value(setting)
-            if setting.data_type is bool:
-                value = parse_bool(value)
+
+            # we want the value from the form, i.e. in case of a POST
+            # request with validation errors.  we also want to make
+            # sure value is JSON-compatible, but we must represent it
+            # as Python value here, and it will be JSON-encoded later.
+            value = form.get_vuejs_model_value(field)
+            value = json.loads(value)
             s['value'] = value
+
+            # specify error / message if applicable
+            # TODO: not entirely clear to me why some field errors are
+            # represented differently?  presumably it depends on
+            # whether Buefy is used by the theme.
             if field.error:
-                s['error_messages'] = field.error_messages()
+                s['error'] = True
+                if isinstance(field.error, colander.Invalid):
+                    s['error_messages'] = [field.errormsg]
+                else:
+                    s['error_messages'] = field.error_messages()
+
             grouped[setting.group].append(s)
 
         data = []
@@ -259,7 +288,8 @@ class AppSettingsView(View):
                 value = ', '.join(entries)
             else:
                 value = six.text_type(value)
-            api.save_setting(Session(), legacy_name, value)
+            app = self.get_rattail_app()
+            app.save_setting(Session(), legacy_name, value)
 
     def clean_list_entry(self, value):
         value = value.strip()
