@@ -26,24 +26,27 @@ Views for app upgrades
 
 from __future__ import unicode_literals, absolute_import
 
+import json
 import os
 import re
 import logging
+import warnings
 
 import six
-from sqlalchemy import orm
+import sqlalchemy as sa
 
 from rattail.core import Object
 from rattail.db import model, Session as RattailSession
 from rattail.time import make_utc
 from rattail.threads import Thread
-from rattail.upgrades import get_upgrade_handler
+from rattail.util import OrderedDict
 
 from deform import widget as dfwidget
 from webhelpers2.html import tags, HTML
 
 from tailbone.views import MasterView
 from tailbone.progress import get_progress_session #, SessionProgress
+from tailbone.config import should_expose_websockets
 
 
 log = logging.getLogger(__name__)
@@ -56,6 +59,7 @@ class UpgradeView(MasterView):
     model_class = model.Upgrade
     downloadable = True
     cloneable = True
+    configurable = True
     executable = True
     execute_progress_template = '/upgrade.mako'
     execute_progress_initial_msg = "Upgrading"
@@ -68,6 +72,7 @@ class UpgradeView(MasterView):
     }
 
     grid_columns = [
+        'system',
         'created',
         'description',
         # 'not_until',
@@ -78,6 +83,7 @@ class UpgradeView(MasterView):
     ]
 
     form_fields = [
+        'system',
         'description',
         # 'not_until',
         # 'requirements',
@@ -97,28 +103,40 @@ class UpgradeView(MasterView):
 
     def __init__(self, request):
         super(UpgradeView, self).__init__(request)
-        self.handler = self.get_handler()
 
-    def get_handler(self):
-        """
-        Returns the ``UpgradeHandler`` instance for the view.  The handler
-        factory for this may be defined by config, e.g.:
+        if hasattr(self, 'get_handler'):
+            warnings.warn("defining get_handler() is deprecated.  please "
+                          "override AppHandler.get_upgrade_handler() instead",
+                          DeprecationWarning, stacklevel=2)
+            self.upgrade_handler = self.get_handler()
 
-        .. code-block:: ini
+        else:
+            app = self.get_rattail_app()
+            self.upgrade_handler = app.get_upgrade_handler()
 
-           [rattail.upgrades]
-           handler = myapp.upgrades:CustomUpgradeHandler
-        """
-        return get_upgrade_handler(self.rattail_config)
+    @property
+    def handler(self):
+        warnings.warn("handler attribute is deprecated; "
+                      "please use upgrade_handler instead",
+                      DeprecationWarning, stacklevel=2)
+        return self.upgrade_handler
 
     def configure_grid(self, g):
         super(UpgradeView, self).configure_grid(g)
+
+        # system
+        systems = self.upgrade_handler.get_all_systems()
+        systems_enum = dict([(s['key'], s['label']) for s in systems])
+        g.set_enum('system', systems_enum)
+
         g.set_joiner('executed_by', lambda q: q.join(model.User, model.User.uuid == model.Upgrade.executed_by_uuid).outerjoin(model.Person))
         g.set_sorter('executed_by', model.Person.display_name)
         g.set_enum('status_code', self.enum.UPGRADE_STATUS)
         g.set_type('created', 'datetime')
         g.set_type('executed', 'datetime')
         g.set_sort_defaults('created', 'desc')
+
+        g.set_link('system')
         g.set_link('created')
         g.set_link('description')
         # g.set_link('not_until')
@@ -157,12 +175,22 @@ class UpgradeView(MasterView):
         super(UpgradeView, self).configure_form(f)
         upgrade = f.model_instance
 
+        # system
+        systems = self.upgrade_handler.get_all_systems()
+        systems_enum = OrderedDict([(s['key'], s['label'])
+                                    for s in systems])
+        f.set_enum('system', systems_enum)
+        f.set_required('system')
+        if self.creating:
+            if len(systems) == 1:
+                f.set_default('system', list(systems_enum)[0])
+
         # status_code
         if self.creating:
             f.remove_field('status_code')
         else:
             f.set_enum('status_code', self.enum.UPGRADE_STATUS)
-            # f.set_readonly('status_code')
+            f.set_renderer('status_code', self.render_status_code)
 
         # executing
         if not self.editing:
@@ -174,7 +202,15 @@ class UpgradeView(MasterView):
         f.set_widget('notes', dfwidget.TextAreaWidget(cols=80, rows=8))
         f.set_renderer('stdout_file', self.render_stdout_file)
         f.set_renderer('stderr_file', self.render_stdout_file)
-        f.set_renderer('package_diff', self.render_package_diff)
+
+        # package_diff
+        if self.viewing and upgrade.executed and (
+                upgrade.system == 'rattail'
+                or not upgrade.system):
+            f.set_renderer('package_diff', self.render_package_diff)
+        else:
+            f.remove_field('package_diff')
+
         # f.set_readonly('created')
         # f.set_readonly('created_by')
         f.set_readonly('executed')
@@ -202,14 +238,41 @@ class UpgradeView(MasterView):
             f.set_default('enabled', True)
 
         if not self.viewing or not upgrade.executed:
-            f.remove_field('package_diff')
             f.remove_field('exit_code')
 
+    def render_status_code(self, upgrade, field):
+        code = getattr(upgrade, field)
+        text = self.enum.UPGRADE_STATUS[code]
+
+        if self.get_use_buefy():
+            if code == self.enum.UPGRADE_STATUS_EXECUTING:
+
+                text = HTML.tag('span', c=[text])
+
+                button = HTML.tag('b-button',
+                                  type='is-warning',
+                                  icon_pack='fas',
+                                  icon_left='sad-tear',
+                                  c=['{{ declareFailureSubmitting ? "Working, please wait..." : "Declare Failure" }}'],
+                                  **{':disabled': 'declareFailureSubmitting',
+                                     '@click': 'declareFailureClick'})
+
+                return HTML.tag('div', class_='level', c=[
+                    HTML.tag('div', class_='level-left', c=[
+                        HTML.tag('div', class_='level-item', c=[text]),
+                        HTML.tag('div', class_='level-item', c=[button]),
+                    ]),
+                ])
+
+        # just show status per normal
+        return text
+
     def configure_clone_form(self, f):
-        f.fields = ['description', 'notes', 'enabled']
+        f.fields = ['system', 'description', 'notes', 'enabled']
 
     def clone_instance(self, original):
         cloned = self.model_class()
+        cloned.system = original.system
         cloned.created = make_utc()
         cloned.created_by = self.request.user
         cloned.description = original.description
@@ -412,13 +475,29 @@ class UpgradeView(MasterView):
     #     key = '{}.execute'.format(self.get_grid_key())
     #     return SessionProgress(self.request, key, session_type='file')
 
-    def execute_instance(self, upgrade, user, **kwargs):
-        session = orm.object_session(upgrade)
-        self.handler.mark_executing(upgrade)
+    def executable_instance(self, upgrade):
+        if upgrade.executed:
+            return False
+        if upgrade.status_code != self.enum.UPGRADE_STATUS_PENDING:
+            return False
+        return True
+
+    def execute_instance(self, upgrade, user, progress=None, **kwargs):
+        app = self.get_rattail_app()
+        session = app.get_session(upgrade)
+
+        # record the fact that execution has begun for this ugprade
+        self.upgrade_handler.mark_executing(upgrade)
         session.commit()
-        self.handler.do_execute(upgrade, user, **kwargs)
-        return ("Execution has finished, for better or worse.  "
-                "You may need to restart your web app.")
+
+        # let handler execute the upgrade
+        self.upgrade_handler.do_execute(upgrade, user, **kwargs)
+
+        # success msg
+        msg = "Execution has finished, for better or worse."
+        if not upgrade.system or upgrade.system == 'rattail':
+            msg += "  You may need to restart your web app."
+        return msg
 
     def execute_progress(self):
         upgrade = self.get_instance()
@@ -446,31 +525,105 @@ class UpgradeView(MasterView):
 
         return data
 
+    def declare_failure(self):
+        upgrade = self.get_instance()
+        if upgrade.executing and upgrade.status_code == self.enum.UPGRADE_STATUS_EXECUTING:
+            upgrade.executing = False
+            upgrade.status_code = self.enum.UPGRADE_STATUS_FAILED
+            self.request.session.flash("Upgrade was declared a failure.", 'warning')
+        else:
+            self.request.session.flash("Upgrade was not currently executing!  "
+                                       "So it was not declared a failure.",
+                                       'error')
+        return self.redirect(self.get_action_url('view', upgrade))
+
     def delete_instance(self, upgrade):
         self.handler.delete_files(upgrade)
         super(UpgradeView, self).delete_instance(upgrade)
 
+    def configure_get_context(self, **kwargs):
+        context = super(UpgradeView, self).configure_get_context(**kwargs)
+
+        context['upgrade_systems'] = self.upgrade_handler.get_all_systems()
+
+        return context
+
+    def configure_gather_settings(self, data):
+        settings = super(UpgradeView, self).configure_gather_settings(data)
+
+        keys = []
+        for system in json.loads(data['upgrade_systems']):
+            key = system['key']
+            if key == 'rattail':
+                settings.append({'name': 'rattail.upgrades.command',
+                                 'value': system['command']})
+            else:
+                keys.append(key)
+                settings.append({'name': 'rattail.upgrades.system.{}.label'.format(key),
+                                 'value': system['label']})
+                settings.append({'name': 'rattail.upgrades.system.{}.command'.format(key),
+                                 'value': system['command']})
+        if keys:
+            settings.append({'name': 'rattail.upgrades.systems',
+                             'value': ', '.join(keys)})
+
+        return settings
+
+    def configure_remove_settings(self):
+        super(UpgradeView, self).configure_remove_settings()
+        app = self.get_rattail_app()
+        model = self.model
+
+        to_delete = self.Session.query(model.Setting)\
+                           .filter(sa.or_(
+                               model.Setting.name == 'rattail.upgrades.command',
+                               model.Setting.name == 'rattail.upgrades.systems',
+                               model.Setting.name.like('rattail.upgrades.system.%.label'),
+                               model.Setting.name.like('rattail.upgrades.system.%.command')))\
+                           .all()
+
+        for setting in to_delete:
+            app.delete_setting(self.Session(), setting.name)
+
     @classmethod
     def defaults(cls, config):
+        cls._defaults(config)
+        cls._upgrade_defaults(config)
+
+    @classmethod
+    def _upgrade_defaults(cls, config):
         route_prefix = cls.get_route_prefix()
-        url_prefix = cls.get_url_prefix()
         permission_prefix = cls.get_permission_prefix()
+        instance_url_prefix = cls.get_instance_url_prefix()
         model_key = cls.get_model_key()
 
         # execution progress
-        config.add_route('{}.execute_progress'.format(route_prefix), '{}/{{{}}}/execute/progress'.format(url_prefix, model_key))
-        config.add_view(cls, attr='execute_progress', route_name='{}.execute_progress'.format(route_prefix),
-                        permission='{}.execute'.format(permission_prefix), renderer='json')
+        config.add_route('{}.execute_progress'.format(route_prefix),
+                         '{}/execute/progress'.format(instance_url_prefix))
+        config.add_view(cls, attr='execute_progress',
+                        route_name='{}.execute_progress'.format(route_prefix),
+                        permission='{}.execute'.format(permission_prefix),
+                        renderer='json')
 
-        cls._defaults(config)
+        # declare failure
+        config.add_route('{}.declare_failure'.format(route_prefix),
+                         '{}/declare-failure'.format(instance_url_prefix),
+                         request_method='POST')
+        config.add_view(cls, attr='declare_failure',
+                        route_name='{}.declare_failure'.format(route_prefix),
+                        permission='{}.execute'.format(permission_prefix))
 
 
 def defaults(config, **kwargs):
     base = globals()
+    rattail_config = config.registry['rattail_config']
 
     UpgradeView = kwargs.get('UpgradeView', base['UpgradeView'])
     UpgradeView.defaults(config)
 
+    if should_expose_websockets(rattail_config):
+        config.include('tailbone.views.asgi.upgrades')
+
 
 def includeme(config):
     defaults(config)
