@@ -27,6 +27,7 @@ User Views
 from __future__ import unicode_literals, absolute_import
 
 import six
+import sqlalchemy as sa
 from sqlalchemy import orm
 
 from rattail.db.model import User, UserEvent
@@ -276,13 +277,21 @@ class UserView(PrincipalMasterView):
             authenticated_role(self.Session()).uuid,
         ]
 
-        # only allow "root" user to change admin role membership
+        # only allow "root" user to change true admin role membership
         if not self.request.is_root:
             excluded.append(administrator_role(self.Session()).uuid)
 
-        return self.Session.query(model.Role)\
-                           .filter(~model.Role.uuid.in_(excluded))\
-                           .order_by(model.Role.name)
+        # basic list, minus exclusions so far
+        roles = self.Session.query(model.Role)\
+                            .filter(~model.Role.uuid.in_(excluded))
+
+        # only allow "admin" user to change admin-ish role memberships
+        if not self.request.is_admin:
+            roles = roles.filter(sa.or_(
+                model.Role.adminish == False,
+                model.Role.adminish == None))
+
+        return roles.order_by(model.Role.name)
 
     def objectify(self, form, data=None):
         model = self.model
